"""
Bootstrapping

Contains a lot of stuff that is reused continously in all the packages

@author José Antonio García-Díaz <joseantonio.garcia8@um.es>
@author Rafael Valencia-Garcia <valencia@um.es>
"""

# For reproductibility, we set a global seed that will be shared on tensorflow, numpy, etc...
seed = 1 


# Import OS to set the environment variables
import os


# Configure TF and CUDA for reproductilibty and to avoid INFO and WARNING messages
os.environ['TF_CPP_MIN_LOG_LEVEL'] = '2' 
os.environ['CUDA_DEVICE_ORDER'] = 'PCI_BUS_ID'
os.environ['CUDA_VISIBLE_DEVICES'] = '0'
os.environ['TF_CUDNN_DETERMINISTIC'] = 'true'
os.environ['TF_DETERMINISTIC_OPS'] = 'true'
os.environ['OMP_NUM_THREADS'] = '32'
os.environ['TOKENIZERS_PARALLELISM'] = 'false'


# Configure WANDB
os.environ['WANDB_DISABLED'] = 'true'


# Import TORCH to determine if CUDA is available or not
import torch


# @var CUDA_available Boolean
CUDA_available = torch.cuda.is_available ();


# Configure deterministic operations
if not CUDA_available:
    os.environ['CUDA_VISIBLE_DEVICES'] = ''
    os.environ['TF_DETERMINISTIC_OPS'] = 'true'


# Import libreries that can generate stochastic behaviour
import random
import numpy as np
import pandas as pd
import tensorflow


# Seed random generators
# @todo improve https://scikit-learn.org/stable/common_pitfalls.html#randomness
def set_random_seed (seed):
    os.environ['PYTHONHASHSEED'] = str (seed)
    random.seed (seed)
    np.random.seed (seed)
    tensorflow.compat.v1.set_random_seed (seed)
    tensorflow.random.set_seed (seed)
    tensorflow.keras.utils.set_random_seed (seed)
    torch.manual_seed (seed)

set_random_seed (seed)


# @var NUM_PARALLEL_EXEC_UNITS uint
NUM_PARALLEL_EXEC_UNITS = 8


# Keras and tensorflow parallelism
tensorflow.config.threading.set_inter_op_parallelism_threads (NUM_PARALLEL_EXEC_UNITS)

# sess = tensorflow.compat.v1.Session (graph = tensorflow.compat.v1.get_default_graph (), config = session_conf)
# tensorflow.compat.v1.keras.backend.set_session (sess)


# Configure pretty print options
np.set_printoptions (formatter = {'float_kind': '{:.5f}'.format})
pd.set_option ('display.float_format', lambda x: '%.3f' % x)