import csv
import json
import itertools
import numpy as np
import string
import os
import pandas as pd
import sys

from tqdm import tqdm
from .Dataset import Dataset
from scipy import stats


class DatasetFineGrainEmotionAnaylsis (Dataset):
  """
  DatasetFineGrainEmotionAnaylsis
  
  @link https://github.com/AlejandroSalme/TFG-Corpus_AnalisisEmociones_UMU/blob/main/datasets/spanish_sentiment.tsv
  
  @extends Dataset
  """

  def __init__ (self, dataset, options, corpus = '', task = '', refresh = False):
    """
    @inherit
    """
    Dataset.__init__ (self, dataset, options, corpus, task, refresh)
  
  def compile (self):
    
    # @var df DataFrame
    df = pd.read_csv (self.get_working_dir ('dataset/dataset.csv'), sep = '|')
    df = df.rename (columns = {'emotion': 'label'})
    
    
    #  @var df_reannoated DataFrame
    df_reannoated = pd.read_csv (self.get_working_dir ('dataset/suicide-reannoated.csv'))
    
    
    # @var ids_to_remove List
    ids_to_remove = df_reannoated['ID'].unique ()


    # Remove long tweets from suicidal
    df = df.drop (index = ids_to_remove)

    
    # Reassign and concat
    df_reannoated = df_reannoated.loc[df_reannoated['valido'] == 1]
    df_reannoated = df_reannoated.rename (columns = {
        'sentiment': 'label', 
        'text': 'tweet'
    })
    df_reannoated = df_reannoated[['tweet', 'label']]
    
    df = pd.concat ([df, df_reannoated], axis = 0);
    df = df.reset_index (drop = True)
    
    
    # Remove blank lines
    df = df.replace (to_replace = [r"\\t|\\n|\\r", "\t|\n|\r"], value = ["", ""], regex = True)
    
    
    # filter language
    df = self.calculate_language (df)
    df = df.loc[df['language'] == 'es']
    
    
    # Some cleaning
    df['tweet'] = df['tweet'].str.replace ('TUSERUSER', '', regex = False)
    df['tweet'] = df['tweet'].str.replace ('RT', '', regex = False)
    df['tweet'] = df['tweet'].str.replace ('TURLURL', '', regex = False)
    df['tweet'] = df['tweet'].str.replace (' !', '!', regex = False)
    df['tweet'] = df['tweet'].str.replace (' : ', ': ', regex = False)
    df['tweet'] = df['tweet'].str.replace (' , ', ', ', regex = False)
    df['tweet'] = df['tweet'].str.replace (' , ', ', ', regex = False)
    df['tweet'] = df['tweet'].str.replace (r'^:\s+', '', regex = True)
    df['tweet'] = df['tweet'].str.replace (r"\**editar\**:\s*", '', regex = True, case = False)
    
    
    # Strip
    df['tweet'] = df['tweet'].str.strip ()
    
    
    # Create default splits
    df = self.assign_default_splits (df)
    
    
    # Store this data on disk
    self.save_on_disk (df)
    
    
    # Return
    return df
    
    