"""
ModelResolver

@author José Antonio García-Díaz <joseantonio.garcia8@um.es>
@author Rafael Valencia-Garcia <valencia@um.es>
"""

import json
import sys
import os.path

class ModelResolver ():
    """
    ModelResolver
    """
    
    def get_choices (self):
        """
        get_choices
        
        @return List
        """
        return [
            'transformers',
            'transformers-lf',
            'machine-learning',
            'deep-learning',
            'ensemble',
            'tf-idf'
        ]
        
        
    def get_default_choice (self):
        """
        get_default_choice
        
        @return String
        """
        return "deep-learning"
    
    def get_from_resume (self, resume):
        """
        @param self 
        @param resume Dict
        """
        
        # @var model
        model = self.get (resume['model'] if 'model' in resume else self.get_default_choice ())
        model.set_folder (resume['folder'])
        
        
        # @var model_type String
        model_type = resume['model']
    

        # Set the pretrained model using with transformers
        if model_type == 'transformers':
            model.set_pretrained_model (resume['pretrained_model'])


        # Configure the ensemble
        if model_type == 'ensemble':
            model.set_ensemble_strategy (resume['strategy'])
            model.add_models (resume['models'])
        
        return model
        
        
    def get (self, model = 'machine-learning'):
        """
        @param model string
        """
        
        if 'transformers' == model:
            from .TransformerModel import TransformerModel
            return TransformerModel ()
            
        if 'machine-learning' == model:
            from .ClassicMachineLearningTechniques import ClassicMachineLearningTechniques
            return ClassicMachineLearningTechniques ()
            
        if 'deep-learning' == model:
            from .DeepLearningTechniques import DeepLearningTechniques
            return DeepLearningTechniques ()

        if 'ensemble' == model:
            from .EnsembleModel import EnsembleModel
            return EnsembleModel ()

        if 'tf-idf' == model:
            from .TFIDFModel import TFIDFModel
            return TFIDFModel ()