import csv
import io
import os.path
import pandas as pd
import sys

from sklearn.base import TransformerMixin
from sklearn.base import BaseEstimator 


class DummyTransformer (BaseEstimator, TransformerMixin):
    """
    This dummy transformer is used by the dlsmodels as it does not 
    have to generate new features

    """
    
    def __init__ (self, cache_file = ''):
        """
        @param cache_file String
        """
        super ().__init__() 
        
        
        self.cache_file = cache_file


    def transform (self, X, **transform_params):
        
        # Return vectors from cache
        if self.cache_file and os.path.exists (self.cache_file):
            return pd.read_csv (self.cache_file, header = 0, sep = ",")
        
        
        return X
        
    def fit (self, X, y = None, **fit_params):
        return self
