"""
Compile a dataset and all its features

@author José Antonio García-Díaz <joseantonio.garcia8@um.es>
@author Rafael Valencia-Garcia <valencia@um.es>
"""

import sys
import config
import bootstrap
import os.path

from dlsdatasets.DatasetResolver import DatasetResolver
from utils.Parser import DefaultParser


def main ():
    
    # var parser
    parser = DefaultParser (description = 'Generates cleaned versions of the texts')


    # @var text_field String
    text_field = 'tweet'


    # @var text_clean_lowercase_field String
    text_clean_lowercase_field = 'tweet_clean_lowercase'
    
    
    # @var text_clean_field String
    text_clean_field = 'tweet_clean'
    

    # @var args Get arguments
    args = parser.parse_args ()
    
    
    # @var resolver Resolver
    resolver = DatasetResolver ()
    
    
    # @var dataset Dataset
    dataset = resolver.get (args.dataset, args.corpus, args.task, args.force)
    dataset.filename = dataset.get_working_dir (args.task, 'dataset.csv')
    
    
    # @var df Dataframe
    df = dataset.get ()


    # @var df_split DataFrame We slice only the fields that are not 
    # preprocessed
    df_split = df.loc[df[text_clean_field].isnull ()] \
        if text_clean_field in df.columns \
        else df
        
 

    # Fill NaNs to avoid errors
    df_split[text_field] = df_split[text_field].fillna (value = '')
    

    # Copy tweet
    df_split[text_clean_field] = df_split[text_field]

    
    # Preprocess
    df_split = dataset.preprocess (df_split, field = text_clean_field)


    # Copy clean version to produce the lowercase one
    df_split.loc[:, text_clean_lowercase_field] = df_split[text_clean_field]
    df_split = dataset.preprocess (df_split, pipeline = ['to_lower'], field = text_clean_lowercase_field)


    # Merge the datasets adding the fields to the original dataframe
    df.loc[df_split.index, text_clean_field] = df_split[text_clean_field]
    df.loc[df_split.index, text_clean_lowercase_field] = df_split[text_clean_lowercase_field]

    
    # Save the dataset tagged
    dataset.save_on_disk (df)
    

if __name__ == "__main__":
    main ()